@@ -1,5 +1,5 @@
 package HTTP::Tiny::Paranoid;
-$HTTP::Tiny::Paranoid::VERSION = '0.06';
+$HTTP::Tiny::Paranoid::VERSION = '0.07';
 use strict;
 use warnings;
 
@@ -24,7 +24,6 @@ around _open_handle => sub {
   if ($peer) {
     my ($ips, $error) = $dns->resolve($peer);
     die "$peer: $error\n" if defined $error;
-    die "$peer: did not match resolved IP\n" unless @$ips && $ips->[0] eq $peer;
     $self->$next($req, $scheme, $host, $port, $peer);
   }
   else {
@@ -46,10 +45,6 @@ __END__
 
 HTTP::Tiny::Paranoid - A safer HTTP::Tiny
 
-=head1 VERSION
-
-version 0.06
-
 =head1 SYNOPSIS
 
     # use just like HTTP::Tiny
